@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -30,7 +30,7 @@
 #include <goffice/gtk/goffice-gtk.h>
 
 #include <gsf/gsf-impl-utils.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkhseparator.h>
@@ -210,7 +210,7 @@ static gboolean
 regression_curve_can_add (GogObject const *parent)
 {
 	GogSeries *series = GOG_SERIES (parent);
-	return (series->acceptable_children && GOG_SERIES_ACCEPT_REGRESSION_CURVE) != 0;
+	return (series->acceptable_children & GOG_SERIES_ACCEPT_REGRESSION_CURVE) != 0;
 }
 
 static void
@@ -476,6 +476,7 @@ gog_series_class_init (GogSeriesClass *klass)
 		  regression_curve_pre_remove,
 		  NULL },
 	};
+
 	GObjectClass *gobject_klass = (GObjectClass *) klass;
 	GogObjectClass *gog_klass = (GogObjectClass *) klass;
 	GogStyledObjectClass *style_klass = (GogStyledObjectClass *) klass;
@@ -610,8 +611,8 @@ gog_series_dataset_init (GogDatasetClass *iface)
 }
 
 GSF_CLASS_FULL (GogSeries, gog_series,
-		gog_series_class_init, gog_series_init,
-		GOG_STYLED_OBJECT_TYPE, 0,
+		NULL, NULL, gog_series_class_init, NULL,
+		gog_series_init, GOG_STYLED_OBJECT_TYPE, 0,
 		GSF_INTERFACE (gog_series_dataset_init, GOG_DATASET_TYPE))
 
 /**
